# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.chart2
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_chart_type import XChartType as XChartType_ad200b38

class XChartTypeContainer(XInterface_8f010a43):
    """

    See Also:
        `API XChartTypeContainer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart2_1_1XChartTypeContainer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2'
    __ooo_full_ns__: str = 'com.sun.star.chart2.XChartTypeContainer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.chart2.XChartTypeContainer'

    @abstractmethod
    def addChartType(self, aChartType: 'XChartType_ad200b38') -> None:
        """
        add a chart type to the chart type container

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def getChartTypes(self) -> 'typing.Tuple[XChartType_ad200b38, ...]':
        """
        retrieve all chart types
        """
        ...
    @abstractmethod
    def removeChartType(self, aChartType: 'XChartType_ad200b38') -> None:
        """
        removes one data series from the chart type container.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...
    @abstractmethod
    def setChartTypes(self, aChartTypes: 'typing.Tuple[XChartType_ad200b38, ...]') -> None:
        """
        set all chart types

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XChartTypeContainer']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.io
from .x_active_data_sink import XActiveDataSink as XActiveDataSink_b8d00ba3
from .x_connectable import XConnectable as XConnectable_980a0a96
from .x_data_input_stream import XDataInputStream as XDataInputStream_c56e0c2e

class DataInputStream(XActiveDataSink_b8d00ba3, XConnectable_980a0a96, XDataInputStream_c56e0c2e):
    """
    Service Class

    reads structured data from a chained XInputStream.
    
    An implementation of this service in general does not need to buffer data itself.

    See Also:
        `API DataInputStream <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1io_1_1DataInputStream.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.io'
    __ooo_full_ns__: str = 'com.sun.star.io.DataInputStream'
    __ooo_type_name__: str = 'service'



__all__ = ['DataInputStream']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class MessageBoxResults(metaclass=UnoConstMeta, type_name="com.sun.star.awt.MessageBoxResults", name_space="com.sun.star.awt"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.awt.MessageBoxResults``"""
        pass

    class MessageBoxResultsEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.awt.MessageBoxResults", name_space="com.sun.star.awt"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.awt.MessageBoxResults`` as Enum values"""
        pass

else:
    from ...lo.awt.message_box_results import MessageBoxResults as MessageBoxResults

    class MessageBoxResultsEnum(IntEnum):
        """
        Enum of Const Class MessageBoxResults

        These constants are used to specify a result of executing a XMessageBox.
        
        **since**
        
            LibreOffice 4.2
        """
        CANCEL = MessageBoxResults.CANCEL
        """
        The user canceled the XMessageBox, by pressing \"Cancel\" or \"Abort\" button.
        """
        OK = MessageBoxResults.OK
        """
        The user pressed the \"Ok\" button.
        """
        YES = MessageBoxResults.YES
        """
        The user pressed the \"Yes\" button.
        """
        NO = MessageBoxResults.NO
        """
        The user pressed the \"No\" button.
        """
        RETRY = MessageBoxResults.RETRY
        """
        The user pressed the \"Retry\" button.
        """
        IGNORE = MessageBoxResults.IGNORE
        """
        The user pressed the \"Ignore\" button.
        """

__all__ = ['MessageBoxResults', 'MessageBoxResultsEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.chart
import typing
from abc import abstractmethod
from ..drawing.x_shape import XShape as XShape_8fd00a3d
if typing.TYPE_CHECKING:
    from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa

class XDiagram(XShape_8fd00a3d):
    """
    manages the diagram of the chart document.

    See Also:
        `API XDiagram <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart_1_1XDiagram.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.XDiagram'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.chart.XDiagram'

    @abstractmethod
    def getDataPointProperties(self, nCol: int, nRow: int) -> 'XPropertySet_bc180bfa':
        """

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def getDataRowProperties(self, nRow: int) -> 'XPropertySet_bc180bfa':
        """

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def getDiagramType(self) -> str:
        """
        """
        ...

__all__ = ['XDiagram']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.form
from .x_form_component import XFormComponent as XFormComponent_c7fc0c5b

class XForm(XFormComponent_c7fc0c5b):
    """
    identifies a FormComponent as being a (sub-) form.
    
    This interface does not really provide an own functionality, it is only for easier runtime identification of form components.

    See Also:
        `API XForm <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1XForm.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form'
    __ooo_full_ns__: str = 'com.sun.star.form.XForm'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.form.XForm'


__all__ = ['XForm']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.view
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XViewCursor(XInterface_8f010a43):
    """
    makes it possible to move a cursor up/down/left/right within laid out text.

    See Also:
        `API XViewCursor <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1view_1_1XViewCursor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.view'
    __ooo_full_ns__: str = 'com.sun.star.view.XViewCursor'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.view.XViewCursor'

    @abstractmethod
    def goDown(self, nCount: int, bExpand: bool) -> bool:
        """
        moves the cursor the specified number of lines down.
        """
        ...
    @abstractmethod
    def goLeft(self, nCount: int, bExpand: bool) -> bool:
        """
        moves the cursor the specified number of characters to the left.
        """
        ...
    @abstractmethod
    def goRight(self, nCount: int, bExpand: bool) -> bool:
        """
        moves the cursor the specified number of characters to the right.
        """
        ...
    @abstractmethod
    def goUp(self, nCount: int, bExpand: bool) -> bool:
        """
        moves the cursor the specified number of lines up.
        """
        ...

__all__ = ['XViewCursor']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.embed
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73

class XCommonEmbedPersist(XInterface_8f010a43):
    """
    specifies common implementation for embedded objects and links persistence.

    See Also:
        `API XCommonEmbedPersist <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1embed_1_1XCommonEmbedPersist.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.XCommonEmbedPersist'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.embed.XCommonEmbedPersist'

    @abstractmethod
    def isReadonly(self) -> bool:
        """
        allows to detect if the data store is read-only.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
        """
        ...
    @abstractmethod
    def reload(self, aMediaArgs: 'typing.Tuple[PropertyValue_c9610c73, ...]', aObjectArgs: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> None:
        """
        lets the object or the link reload itself.
        
        If the object has persistence it will be reloaded from its persistent entry.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.embed.WrongStateException: ``WrongStateException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def storeOwn(self) -> None:
        """
        lets the object or the link store itself.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...

__all__ = ['XCommonEmbedPersist']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ...lo.resource.missing_resource_exception import MissingResourceException as MissingResourceException
from ...lo.resource.string_resource import StringResource as StringResource
from ...lo.resource.string_resource_with_location import StringResourceWithLocation as StringResourceWithLocation
from ...lo.resource.string_resource_with_storage import StringResourceWithStorage as StringResourceWithStorage
from ...lo.resource.x_string_resource_manager import XStringResourceManager as XStringResourceManager
from ...lo.resource.x_string_resource_persistence import XStringResourcePersistence as XStringResourcePersistence
from ...lo.resource.x_string_resource_resolver import XStringResourceResolver as XStringResourceResolver
from ...lo.resource.x_string_resource_supplier import XStringResourceSupplier as XStringResourceSupplier
from ...lo.resource.x_string_resource_with_location import XStringResourceWithLocation as XStringResourceWithLocation
from ...lo.resource.x_string_resource_with_storage import XStringResourceWithStorage as XStringResourceWithStorage



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdb
from ..container.x_hierarchical_name import XHierarchicalName as XHierarchicalName_3a4b0f63
from ..ucb.content import Content as Content_70d9091d

class DefinitionContent(Content_70d9091d, XHierarchicalName_3a4b0f63):
    """
    Service Class

    defines the basic functionality for an object in the hierarchy of sub documents of an OfficeDatabaseDocument.
    
    **since**
    
        OOo 3.3

    See Also:
        `API DefinitionContent <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1DefinitionContent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.DefinitionContent'
    __ooo_type_name__: str = 'service'



__all__ = ['DefinitionContent']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.animations


class AnimationAdditiveMode(object):
    """
    Const Class

    Specifies the additive mode for the animation.

    See Also:
        `API AnimationAdditiveMode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1animations_1_1AnimationAdditiveMode.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.animations'
    __ooo_full_ns__: str = 'com.sun.star.animations.AnimationAdditiveMode'
    __ooo_type_name__: str = 'const'

    BASE = 0
    SUM = 1
    REPLACE = 2
    MULTIPLY = 3
    NONE = 4

__all__ = ['AnimationAdditiveMode']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
import typing
from abc import abstractproperty, ABC
if typing.TYPE_CHECKING:
    from .function_argument import FunctionArgument as FunctionArgument_f1080daa

class FunctionDescription(ABC):
    """
    Service Class

    collects all properties used to describe a function.

    See Also:
        `API FunctionDescription <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1FunctionDescription.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.FunctionDescription'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Arguments(self) -> 'typing.Tuple[FunctionArgument_f1080daa, ...]':
        """
        returns a sequence of localized descriptions of the function's arguments (in the order specified by the function).
        """
        ...

    @abstractproperty
    def Category(self) -> int:
        """
        returns the function's category.
        """
        ...

    @abstractproperty
    def Description(self) -> str:
        """
        returns a localized description of the function.
        """
        ...

    @abstractproperty
    def Id(self) -> int:
        """
        returns the function's unique identifier.
        """
        ...

    @abstractproperty
    def Name(self) -> str:
        """
        returns the localized function's name.
        """
        ...



__all__ = ['FunctionDescription']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdbcx
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XDrop(XInterface_8f010a43):
    """
    provides methods to remove an element of its container and to drop it from the related database.

    See Also:
        `API XDrop <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbcx_1_1XDrop.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbcx'
    __ooo_full_ns__: str = 'com.sun.star.sdbcx.XDrop'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdbcx.XDrop'

    @abstractmethod
    def dropByIndex(self, index: int) -> None:
        """
        drops an object of the related container identified by its position.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def dropByName(self, elementName: str) -> None:
        """
        drops an object of the related container identified by its name.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...

__all__ = ['XDrop']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.style
from .page_properties import PageProperties as PageProperties_d7220ce3
from .style import Style as Style_7336094a

class PageStyle(PageProperties_d7220ce3, Style_7336094a):
    """
    Service Class

    contributes common properties of page styles.

    See Also:
        `API PageStyle <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1style_1_1PageStyle.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.style'
    __ooo_full_ns__: str = 'com.sun.star.style.PageStyle'
    __ooo_type_name__: str = 'service'



__all__ = ['PageStyle']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ucb
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .content_info import ContentInfo as ContentInfo_98f60aa9
    from .x_content import XContent as XContent_79db0975

class XContentCreator(XInterface_8f010a43):
    """
    A creator for new (persistent) contents, like file system folders.
    
    Creation of a new (persistent) content:
    
    This interface is deprecated. Use Content property \"CreatableContentsInfo\" and command \"createNewContent\" instead.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XContentCreator <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ucb_1_1XContentCreator.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.XContentCreator'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.ucb.XContentCreator'

    @abstractmethod
    def createNewContent(self, Info: 'ContentInfo_98f60aa9') -> 'XContent_79db0975':
        """
        creates a new content of given type.
        """
        ...
    @abstractmethod
    def queryCreatableContentsInfo(self) -> 'typing.Tuple[ContentInfo_98f60aa9, ...]':
        """
        returns a list with information about the creatable contents.
        """
        ...

__all__ = ['XContentCreator']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_spin_listener import XSpinListener as XSpinListener_afee0b8c

class XSpinField(XInterface_8f010a43):
    """
    gives access to the value of a spin field and makes it possible to register for spin events.

    See Also:
        `API XSpinField <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XSpinField.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XSpinField'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XSpinField'

    @abstractmethod
    def addSpinListener(self, l: 'XSpinListener_afee0b8c') -> None:
        """
        registers a listener for spin events.
        """
        ...
    @abstractmethod
    def down(self) -> None:
        """
        decreases the value by one step.
        """
        ...
    @abstractmethod
    def enableRepeat(self, bRepeat: bool) -> None:
        """
        enables/disables automatic repeat mode.
        """
        ...
    @abstractmethod
    def first(self) -> None:
        """
        sets the value to the previously set lower value.
        """
        ...
    @abstractmethod
    def last(self) -> None:
        """
        sets the value to the previously set upper value.
        """
        ...
    @abstractmethod
    def removeSpinListener(self, l: 'XSpinListener_afee0b8c') -> None:
        """
        unregisters a listener for spin events.
        """
        ...
    @abstractmethod
    def up(self) -> None:
        """
        increases the value by one step.
        """
        ...

__all__ = ['XSpinField']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from abc import abstractmethod
from .x_sheet_condition import XSheetCondition as XSheetCondition_e1940d19

class XSheetCondition2(XSheetCondition_e1940d19):
    """
    provides methods to access the settings of a condition in a conditional format or data validation.

    See Also:
        `API XSheetCondition2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetCondition2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XSheetCondition2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XSheetCondition2'

    @abstractmethod
    def getConditionOperator(self) -> int:
        """
        returns the operator in the condition (new interface).
        """
        ...
    @abstractmethod
    def setConditionOperator(self, nOperator: int) -> None:
        """
        sets the operator in the condition (new interface).
        """
        ...

__all__ = ['XSheetCondition2']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class KeyFunction(metaclass=UnoConstMeta, type_name="com.sun.star.awt.KeyFunction", name_space="com.sun.star.awt"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.awt.KeyFunction``"""
        pass

    class KeyFunctionEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.awt.KeyFunction", name_space="com.sun.star.awt"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.awt.KeyFunction`` as Enum values"""
        pass

else:
    from ...lo.awt.key_function import KeyFunction as KeyFunction

    class KeyFunctionEnum(IntEnum):
        """
        Enum of Const Class KeyFunction

        These values are used to specify logical key functions.
        """
        DONTKNOW = KeyFunction.DONTKNOW
        NEW = KeyFunction.NEW
        OPEN = KeyFunction.OPEN
        SAVE = KeyFunction.SAVE
        SAVEAS = KeyFunction.SAVEAS
        PRINT = KeyFunction.PRINT
        CLOSE = KeyFunction.CLOSE
        QUIT = KeyFunction.QUIT
        CUT = KeyFunction.CUT
        COPY = KeyFunction.COPY
        PASTE = KeyFunction.PASTE
        UNDO = KeyFunction.UNDO
        REDO = KeyFunction.REDO
        DELETE = KeyFunction.DELETE
        REPEAT = KeyFunction.REPEAT
        FIND = KeyFunction.FIND
        FINDBACKWARD = KeyFunction.FINDBACKWARD
        PROPERTIES = KeyFunction.PROPERTIES
        FRONT = KeyFunction.FRONT

__all__ = ['KeyFunction', 'KeyFunctionEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.chart
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class DataLabelPlacement(metaclass=UnoConstMeta, type_name="com.sun.star.chart.DataLabelPlacement", name_space="com.sun.star.chart"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.chart.DataLabelPlacement``"""
        pass

    class DataLabelPlacementEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.chart.DataLabelPlacement", name_space="com.sun.star.chart"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.chart.DataLabelPlacement`` as Enum values"""
        pass

else:
    from ...lo.chart.data_label_placement import DataLabelPlacement as DataLabelPlacement

    class DataLabelPlacementEnum(IntEnum):
        """
        Enum of Const Class DataLabelPlacement

        These values specify where the captions/labels of data points are displayed.
        
        **since**
        
            LibreOffice 7.0
        """
        AVOID_OVERLAP = DataLabelPlacement.AVOID_OVERLAP
        CENTER = DataLabelPlacement.CENTER
        TOP = DataLabelPlacement.TOP
        TOP_LEFT = DataLabelPlacement.TOP_LEFT
        LEFT = DataLabelPlacement.LEFT
        BOTTOM_LEFT = DataLabelPlacement.BOTTOM_LEFT
        BOTTOM = DataLabelPlacement.BOTTOM
        BOTTOM_RIGHT = DataLabelPlacement.BOTTOM_RIGHT
        RIGHT = DataLabelPlacement.RIGHT
        TOP_RIGHT = DataLabelPlacement.TOP_RIGHT
        INSIDE = DataLabelPlacement.INSIDE
        OUTSIDE = DataLabelPlacement.OUTSIDE
        NEAR_ORIGIN = DataLabelPlacement.NEAR_ORIGIN
        CUSTOM = DataLabelPlacement.CUSTOM

__all__ = ['DataLabelPlacement', 'DataLabelPlacementEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
from abc import abstractproperty
from ..awt.uno_control import UnoControl as UnoControl_8f2c0a67

class FrameControl(UnoControl_8f2c0a67):
    """
    Service Class

    contains a frame with a desktop component
    
    If the control is visible and has a valid (loadable) component URL, then the FrameControl.Frame property is set. Normally this control can be used for preview functionality inside any UI.

    See Also:
        `API FrameControl <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1frame_1_1FrameControl.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.FrameControl'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def ComponentUrl(self) -> str:
        """
        contains the type of the component which is loaded into the frame, or the document which implicitly specifies the type
        """
        ...

    @abstractproperty
    def Frame(self) -> str:
        """
        the frame held by this control
        
        The Frame is created if the control is shown and the ComponentUrl is set.
        """
        ...



__all__ = ['FrameControl']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdbc


class ProcedureColumn(object):
    """
    Const Class

    indicates the type of a procedure column.

    See Also:
        `API ProcedureColumn <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sdbc_1_1ProcedureColumn.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.ProcedureColumn'
    __ooo_type_name__: str = 'const'

    UNKNOWN = 0
    """
    indicates that the type of the column is unknown.
    
    A possible value for the column COLUMN_TYPE in the com.sun.star.sdbc.XResultSet returned by the method com.sun.star.sdbc.XDatabaseMetaData.getProcedureColumns().
    """
    IN = 1
    """
    indicates that the column stores IN parameters.
    
    A possible value for the column COLUMN_TYPE in the com.sun.star.sdbc.XResultSet returned by the method com.sun.star.sdbc.XDatabaseMetaData.getProcedureColumns().
    """
    INOUT = 2
    """
    indicates that the column stores INOUT parameters.
    
    A possible value for the column COLUMN_TYPE in the com.sun.star.sdbc.XResultSet returned by the method com.sun.star.sdbc.XDatabaseMetaData.getProcedureColumns().
    """
    RESULT = 3
    """
    indicates that the column stores results.
    
    A possible value for the column COLUMN_TYPE in the com.sun.star.sdbc.XResultSet returned by the method com.sun.star.sdbc.XDatabaseMetaData.getProcedureColumns().
    """
    OUT = 4
    """
    indicates that the column stores OUT parameters.
    
    A possible value for the column COLUMN_TYPE in the com.sun.star.sdbc.XResultSet returned by the method com.sun.star.sdbc.XDatabaseMetaData.getProcedureColumns().
    """
    RETURN = 5
    """
    Indicates that the column stores return values.
    
    A possible value for the column COLUMN_TYPE in the com.sun.star.sdbc.XResultSet returned by the method com.sun.star.sdbc.XDatabaseMetaData.getProcedureColumns().
    """

__all__ = ['ProcedureColumn']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.presentation
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class TextAnimationType(metaclass=UnoConstMeta, type_name="com.sun.star.presentation.TextAnimationType", name_space="com.sun.star.presentation"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.presentation.TextAnimationType``"""
        pass

    class TextAnimationTypeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.presentation.TextAnimationType", name_space="com.sun.star.presentation"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.presentation.TextAnimationType`` as Enum values"""
        pass

else:
    from ...lo.presentation.text_animation_type import TextAnimationType as TextAnimationType

    class TextAnimationTypeEnum(IntEnum):
        """
        Enum of Const Class TextAnimationType

        Defines how a target com.sun.star.text.XTextRange is animated inside an com.sun.star.animations.XIterateContainer.
        
        This is stored inside the attribute com.sun.star.animations.XIterateContainer.IterateType.
        """
        BY_PARAGRAPH = TextAnimationType.BY_PARAGRAPH
        """
        the text is animated paragraph by paragraph
        """
        BY_WORD = TextAnimationType.BY_WORD
        """
        the text is animated word by word
        """
        BY_LETTER = TextAnimationType.BY_LETTER
        """
        the text is animated letter by letter.
        """

__all__ = ['TextAnimationType', 'TextAnimationTypeEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.bridge
from .x_bridge import XBridge as XBridge_8e4e0a1a
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from ..lang.x_initialization import XInitialization as XInitialization_d46c0cca

class IiopBridge(XBridge_8e4e0a1a, XComponent_98dc0ab5, XInitialization_d46c0cca):
    """
    Service Class

    Concrete service of the meta service Bridge for iiop.
    
    This bridge works with the iiop protocol.

    See Also:
        `API IiopBridge <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1bridge_1_1IiopBridge.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.bridge'
    __ooo_full_ns__: str = 'com.sun.star.bridge.IiopBridge'
    __ooo_type_name__: str = 'service'



__all__ = ['IiopBridge']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
import typing
from abc import abstractproperty
from .uno_control_model import UnoControlModel as UnoControlModel_c8ce0c58
if typing.TYPE_CHECKING:
    from .font_descriptor import FontDescriptor as FontDescriptor_bc110c0a
    from ..style.vertical_alignment import VerticalAlignment as VerticalAlignment_8d0e12
    from ..util.color import Color as Color_68e908c5
    from ..util.x_number_formats_supplier import XNumberFormatsSupplier as XNumberFormatsSupplier_3afb0fb7

class UnoControlFormattedFieldModel(UnoControlModel_c8ce0c58):
    """
    Service Class

    specifies the standard model of a UnoControlFormattedField .
    
    **since**
    
        OOo 2.0

    See Also:
        `API UnoControlFormattedFieldModel <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFormattedFieldModel.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.UnoControlFormattedFieldModel'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Align(self) -> int:
        """
        specifies the horizontal alignment of the text in the control.
        """
        ...

    @abstractproperty
    def BackgroundColor(self) -> 'Color_68e908c5':
        """
        specifies the background color (RGB) of the control.
        """
        ...

    @abstractproperty
    def Border(self) -> int:
        """
        specifies the border style of the control.
        """
        ...

    @abstractproperty
    def BorderColor(self) -> int:
        """
        specifies the color of the border, if present
        
        Not every border style (see Border) may support coloring. For instance, usually a border with 3D effect will ignore the BorderColor setting.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def EffectiveDefault(self) -> object:
        """
        specifies the default value of the formatted field.
        
        This may be a numeric value (double) or a string, depending on the formatting of the field.
        """
        ...

    @abstractproperty
    def EffectiveMax(self) -> float:
        """
        specifies the maximum value that can be entered.
        
        This property is ignored if the format of the field is no numeric format.
        """
        ...

    @abstractproperty
    def EffectiveMin(self) -> float:
        """
        specifies the minimum value that can be entered.
        
        This property is ignored if the format of the field is no numeric format.
        """
        ...

    @abstractproperty
    def EffectiveValue(self) -> float:
        """
        specifies the current value of the formatted field.
        
        This may be a numeric value (double) or a string, depending on the formatting of the field.
        """
        ...

    @abstractproperty
    def Enabled(self) -> bool:
        """
        determines whether the control is enabled or disabled.
        """
        ...

    @abstractproperty
    def FontDescriptor(self) -> 'FontDescriptor_bc110c0a':
        """
        specifies the font attributes of the text in the control.
        """
        ...

    @abstractproperty
    def FontEmphasisMark(self) -> int:
        """
        specifies the com.sun.star.text.FontEmphasis value of the text in the control.
        """
        ...

    @abstractproperty
    def FontRelief(self) -> int:
        """
        specifies the com.sun.star.text.FontRelief value of the text in the control.
        """
        ...

    @abstractproperty
    def FormatKey(self) -> int:
        """
        specifies the format to be used when formatting the field input and output.
        
        This value is meaningful relative to the FormatsSupplier property only.
        """
        ...

    @abstractproperty
    def FormatsSupplier(self) -> 'XNumberFormatsSupplier_3afb0fb7':
        """
        supplies the formats the field should work with.
        """
        ...

    @abstractproperty
    def HelpText(self) -> str:
        """
        specifies the help text of the control.
        """
        ...

    @abstractproperty
    def HelpURL(self) -> str:
        """
        specifies the help URL of the control.
        """
        ...

    @abstractproperty
    def HideInactiveSelection(self) -> bool:
        """
        specifies whether the selection in the control should be hidden when the control is not active (focused).
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def MaxTextLen(self) -> int:
        """
        specifies the maximum character count.
        
        There's no limitation, if set to 0.
        """
        ...

    @abstractproperty
    def MouseWheelBehavior(self) -> int:
        """
        defines how the mouse wheel can be used to scroll through the control's content.
        
        Usually, the mouse wheel spins the numeric value displayed in the control. Using this property, and one of the MouseWheelBehavior constants, you can control under which circumstances this is possible.
        """
        ...

    @abstractproperty
    def Printable(self) -> bool:
        """
        specifies that the control will be printed with the document.
        """
        ...

    @abstractproperty
    def ReadOnly(self) -> bool:
        """
        specifies that the content of the control cannot be modified by the user.
        """
        ...

    @abstractproperty
    def Repeat(self) -> bool:
        """
        specifies whether the mouse should show repeating behavior, i.e.
        
        repeatedly trigger an action when keeping pressed.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def RepeatDelay(self) -> int:
        """
        specifies the mouse repeat delay, in milliseconds.
        
        When the user presses a mouse in a control area where this triggers an action (such as spinning the value), then usual control implementations allow to repeatedly trigger this action, without the need to release the mouse button and to press it again. The delay between two such triggers is specified with this property.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def Spin(self) -> bool:
        """
        specifies that the control has a spin button.
        """
        ...

    @abstractproperty
    def StrictFormat(self) -> bool:
        """
        specifies that the text is checked during the user input.
        
        This property is optional - not every component implementing this service is required to provide it, as real-time input checking on a formatted field may be pretty expensive.
        """
        ...

    @abstractproperty
    def Tabstop(self) -> bool:
        """
        specifies that the control can be reached with the TAB key.
        """
        ...

    @abstractproperty
    def Text(self) -> str:
        """
        specifies the text displayed in the control.
        """
        ...

    @abstractproperty
    def TextColor(self) -> 'Color_68e908c5':
        """
        specifies the text color (RGB) of the control.
        """
        ...

    @abstractproperty
    def TextLineColor(self) -> 'Color_68e908c5':
        """
        specifies the text line color (RGB) of the control.
        """
        ...

    @abstractproperty
    def TreatAsNumber(self) -> bool:
        """
        specifies that the text is treated as a number.
        """
        ...

    @abstractproperty
    def VerticalAlign(self) -> 'VerticalAlignment_8d0e12':
        """
        specifies the vertical alignment of the text in the control.
        
        **since**
        
            OOo 3.3
        """
        ...

    @abstractproperty
    def WritingMode(self) -> int:
        """
        denotes the writing mode used in the control, as specified in the com.sun.star.text.WritingMode2 constants group.
        
        Only com.sun.star.text.WritingMode2.LR_TB and com.sun.star.text.WritingMode2.RL_TB are supported at the moment.
        
        **since**
        
            OOo 3.1
        """
        ...



__all__ = ['UnoControlFormattedFieldModel']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from ..accessibility.x_accessible_context import XAccessibleContext as XAccessibleContext_8eae119b
from ..accessibility.x_accessible_event_broadcaster import XAccessibleEventBroadcaster as XAccessibleEventBroadcaster_3d811522
from ..accessibility.x_accessible_extended_component import XAccessibleExtendedComponent as XAccessibleExtendedComponent_539d159a

class AccessibleTabBarPage(XAccessibleContext_8eae119b, XAccessibleEventBroadcaster_3d811522, XAccessibleExtendedComponent_539d159a):
    """
    Service Class

    specifies accessibility support for a tabbar page.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API AccessibleTabBarPage <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1AccessibleTabBarPage.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.AccessibleTabBarPage'
    __ooo_type_name__: str = 'service'



__all__ = ['AccessibleTabBarPage']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.datatransfer.dnd
# Libre Office Version: 7.3
from ooo.oenv.env_const import UNO_NONE
from ...lang.event_object import EventObject as EventObject_a3d70b03
from ...uno.x_interface import XInterface as XInterface_8f010a43
import typing


class DropTargetEvent(EventObject_a3d70b03):
    """
    Struct Class

    This class is the base class for DropTargetDragEvent and DropTargetDropEvent.
    
    To access the XDropTarget that originated this event, use the com.sun.star.lang.EventObject.Source member of this object.

    See Also:
        `API DropTargetEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1DropTargetEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.datatransfer.dnd'
    __ooo_full_ns__: str = 'com.sun.star.datatransfer.dnd.DropTargetEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.datatransfer.dnd.DropTargetEvent'
    """Literal Constant ``com.sun.star.datatransfer.dnd.DropTargetEvent``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, Dummy: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Dummy (int, optional): Dummy value.
        """

        if isinstance(Source, DropTargetEvent):
            oth: DropTargetEvent = Source
            self.Source = oth.Source
            self.Dummy = oth.Dummy
            return

        kargs = {
            "Source": Source,
            "Dummy": Dummy,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._dummy = kwargs["Dummy"]
        inst_keys = ('Dummy',)
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def Dummy(self) -> int:
        """
        UNO specification does not allow empty struct definitions.
        """
        return self._dummy
    
    @Dummy.setter
    def Dummy(self, value: int) -> None:
        self._dummy = value


__all__ = ['DropTargetEvent']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdb
import typing
from abc import abstractmethod
from ..sdbc.x_data_source import XDataSource as XDataSource_a2990ae7
if typing.TYPE_CHECKING:
    from .x_database_access_listener import XDatabaseAccessListener as XDatabaseAccessListener_32d80f46
    from ..sdbc.x_connection import XConnection as XConnection_a36a0b0c

class XDatabaseAccess(XDataSource_a2990ae7):
    """
    is not to be used anymore
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XDatabaseAccess <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseAccess.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.XDatabaseAccess'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdb.XDatabaseAccess'

    @abstractmethod
    def addDatabaseAccessListener(self, listener: 'XDatabaseAccessListener_32d80f46') -> None:
        """
        """
        ...
    @abstractmethod
    def getIsolatedConnection(self, user: str, password: str) -> 'XConnection_a36a0b0c':
        """

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def hasConnections(self) -> bool:
        """
        """
        ...
    @abstractmethod
    def removeDatabaseAccessListener(self, listener: 'XDatabaseAccessListener_32d80f46') -> None:
        """
        """
        ...
    @abstractmethod
    def suspendConnections(self) -> bool:
        """

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
        ...

__all__ = ['XDatabaseAccess']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ...lo.packages.encryption_not_allowed_exception import EncryptionNotAllowedException as EncryptionNotAllowedException
from ...lo.packages.no_encryption_exception import NoEncryptionException as NoEncryptionException
from ...lo.packages.no_raw_format_exception import NoRawFormatException as NoRawFormatException
from ...lo.packages.package import Package as Package
from ...lo.packages.package_encryption import PackageEncryption as PackageEncryption
from ...lo.packages.package_folder import PackageFolder as PackageFolder
from ...lo.packages.package_folder_enumeration import PackageFolderEnumeration as PackageFolderEnumeration
from ...lo.packages.package_stream import PackageStream as PackageStream
from ...lo.packages.wrong_password_exception import WrongPasswordException as WrongPasswordException
from ...lo.packages.x_data_sink_encr_support import XDataSinkEncrSupport as XDataSinkEncrSupport
from ...lo.packages.x_package_encryption import XPackageEncryption as XPackageEncryption



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.reflection
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_idl_class import XIdlClass as XIdlClass_d63a0c9a

class XIdlMember(XInterface_8f010a43):
    """
    Base interface for XIdlField2s and XIdlMethods.

    See Also:
        `API XIdlMember <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlMember.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.reflection'
    __ooo_full_ns__: str = 'com.sun.star.reflection.XIdlMember'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.reflection.XIdlMember'

    @abstractmethod
    def getDeclaringClass(self) -> 'XIdlClass_d63a0c9a':
        """
        Returns the declaring type of this field, i.e.
        
        the type having the member declared (interface, enum, struct, exception).
        """
        ...
    @abstractmethod
    def getName(self) -> str:
        """
        Returns the fully-qualified name of the member.
        """
        ...

__all__ = ['XIdlMember']

